summaryrefslogtreecommitdiffstats
path: root/amarok/src/engine/helix/hxplayercontrol.h
diff options
context:
space:
mode:
Diffstat (limited to 'amarok/src/engine/helix/hxplayercontrol.h')
-rw-r--r--amarok/src/engine/helix/hxplayercontrol.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/amarok/src/engine/helix/hxplayercontrol.h b/amarok/src/engine/helix/hxplayercontrol.h
index 760284de..3ffefe90 100644
--- a/amarok/src/engine/helix/hxplayercontrol.h
+++ b/amarok/src/engine/helix/hxplayercontrol.h
@@ -87,7 +87,7 @@ public:
virtual void onContacting(const char */*host*/) {}
virtual void onBuffering(int /*percentage*/) {}
// children send functions
bool sendnotifyuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendinterruptuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendcontacting(const char *host);
@@ -100,7 +100,7 @@ protected:
private:
int m_err;
- pid_t iamparent;
+ pid_t iamtqparent;
int m_index;
int nNumPlayers;
bool m_inited;
@@ -129,7 +129,7 @@ private:
DelayQueue *q;
int *m_current;
int *m_consumed;
- } m_children[2];
+ } m_tqchildren[2];
unsigned long m_volume;
@@ -175,7 +175,7 @@ private:
DEVICE,
SETFADE,
ENABLEEQ,
- UPDATEEQGAINS,
+ UPDATEETQGAINS,
SCOPEBUF,
SCOPECLEAR,
METADATAREQ,
@@ -87,7 +87,7 @@ public:
virtual void onContacting(const char */*host*/) {}
virtual void onBuffering(int /*percentage*/) {}
- // children send functions
+ // tqchildren send functions
bool sendnotifyuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendinterruptuser(unsigned long code, const char *moreinfo, const char *moreinfourl);